==> PathOfBuildingCommunity-Portable-2.7.0.zip: Data/StatDescriptions/minion_spell_skill_stat_descriptions.lua <==
return {
	[1]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="This Spell and Minions have {0}% increased Cast Speed"
				},
				[2]={
					[1]={
						k="negate",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]=-1
						}
					},
					text="This Spell and Minions have {0}% reduced Cast Speed"
				}
			}
		},
		name="cast_speed_incr",
		stats={
			[1]="base_cast_speed_+%"
		}
	},
	[2]={
		lang={
			English={
				[1]={
					[1]={
						k="reminderstring",
						v="ReminderTextLowLife"
					},
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="This Spell and Minions have {0}% increased Cast Speed when on Low Life"
				},
				[2]={
					[1]={
						k="negate",
						v=1
					},
					[2]={
						k="reminderstring",
						v="ReminderTextLowLife"
					},
					limit={
						[1]={
							[1]="#",
							[2]=-1
						}
					},
					text="This Spell and Minions have {0}% reduced Cast Speed when on Low Life"
				}
			}
		},
		name="cast_speed_incr_on_low_life",
		stats={
			[1]="cast_speed_+%_when_on_low_life"
		}
	},
	[3]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="This Spell and Minions have {0}% more Cast Speed"
				},
				[2]={
					[1]={
						k="negate",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]=-1
						}
					},
					text="This Spell and Minions have {0}% less Cast Speed"
				}
			}
		},
		name="multicast_cast_speed_incr",
		stats={
			[1]="support_multicast_cast_speed_+%_final"
		}
	},
	[4]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="This Spell and Minions have {0}% more Cast Speed"
				},
				[2]={
					[1]={
						k="negate",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]=-1
						}
					},
					text="This Spell and Minions have {0}% less Cast Speed"
				}
			}
		},
		name="totem_cast_speed",
		stats={
			[1]="support_spell_totem_cast_speed_+%_final"
		}
	},
	[5]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="Minion's Melee Strike Skills deal Fire-only Splash Damage to Surrounding Targets"
				}
			}
		},
		name="melee_splash_fire_only",
		stats={
			[1]="summon_raging_spirit_melee_splash_fire_damage_only"
		}
	},
	[6]={
		lang={
			English={
				[1]={
					[1]={
						k="reminderstring",
						v="ReminderTextMultipleMines"
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="This Skill and Minions have {0}% chance to throw up to 1 additional Trap or Mine"
				}
			}
		},
		stats={
			[1]="support_additional_trap_mine_%_chance_for_1_additional_trap_mine"
		}
	},
	[7]={
		lang={
			English={
				[1]={
					[1]={
						k="reminderstring",
						v="ReminderTextMultipleMines"
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="This Skill and Minions have {0}% chance to throw up to 2 additional Traps or Mines"
				}
			}
		},
		stats={
			[1]="support_additional_trap_mine_%_chance_for_2_additional_trap_mine"
		}
	},
	[8]={
		lang={
			English={
				[1]={
					[1]={
						k="reminderstring",
						v="ReminderTextMultipleMines"
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="This Skill and Minions have {0}% chance to throw up to 3 additional Traps or Mines"
				}
			}
		},
		stats={
			[1]="support_additional_trap_mine_%_chance_for_3_additional_trap_mine"
		}
	},
	["base_cast_speed_+%"]=1,
	["cast_speed_+%_when_on_low_life"]=2,
	parent="minion_skill_stat_descriptions",
	["summon_raging_spirit_melee_splash_fire_damage_only"]=5,
	["support_additional_trap_mine_%_chance_for_1_additional_trap_mine"]=6,
	["support_additional_trap_mine_%_chance_for_2_additional_trap_mine"]=7,
	["support_additional_trap_mine_%_chance_for_3_additional_trap_mine"]=8,
	["support_multicast_cast_speed_+%_final"]=3,
	["support_spell_totem_cast_speed_+%_final"]=4
}

==> PathOfBuildingCommunity-Portable-2.14.0.zip: Data/StatDescriptions/minion_spell_skill_stat_descriptions.lua <==
return {
	[1]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="This Spell and Minions have {0}% increased Cast Speed"
				},
				[2]={
					[1]={
						k="negate",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]=-1
						}
					},
					text="This Spell and Minions have {0}% reduced Cast Speed"
				}
			}
		},
		name="cast_speed_incr",
		stats={
			[1]="base_cast_speed_+%"
		}
	},
	[2]={
		lang={
			English={
				[1]={
					[1]={
						k="reminderstring",
						v="ReminderTextLowLife"
					},
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="This Spell and Minions have {0}% increased Cast Speed when on Low Life"
				},
				[2]={
					[1]={
						k="negate",
						v=1
					},
					[2]={
						k="reminderstring",
						v="ReminderTextLowLife"
					},
					limit={
						[1]={
							[1]="#",
							[2]=-1
						}
					},
					text="This Spell and Minions have {0}% reduced Cast Speed when on Low Life"
				}
			}
		},
		name="cast_speed_incr_on_low_life",
		stats={
			[1]="cast_speed_+%_when_on_low_life"
		}
	},
	[3]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="This Spell and Minions have {0}% more Cast Speed"
				},
				[2]={
					[1]={
						k="negate",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]=-1
						}
					},
					text="This Spell and Minions have {0}% less Cast Speed"
				}
			}
		},
		name="multicast_cast_speed_incr",
		stats={
			[1]="support_multicast_cast_speed_+%_final"
		}
	},
	[4]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="This Spell and Minions have {0}% more Cast Speed"
				},
				[2]={
					[1]={
						k="negate",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]=-1
						}
					},
					text="This Spell and Minions have {0}% less Cast Speed"
				}
			}
		},
		name="totem_cast_speed",
		stats={
			[1]="support_spell_totem_cast_speed_+%_final"
		}
	},
	[5]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="Minion's Melee Strike Skills deal Fire-only Splash Damage to Surrounding Targets"
				}
			}
		},
		name="melee_splash_fire_only",
		stats={
			[1]="summon_raging_spirit_melee_splash_fire_damage_only"
		}
	},
	[6]={
		lang={
			English={
				[1]={
					[1]={
						k="reminderstring",
						v="ReminderTextMultipleMines"
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="This Skill and Minions have {0}% chance to throw up to 1 additional Trap or Mine"
				}
			}
		},
		name="chance_for_1_additional_trap_mine",
		stats={
			[1]="support_additional_trap_mine_%_chance_for_1_additional_trap_mine"
		}
	},
	[7]={
		lang={
			English={
				[1]={
					[1]={
						k="reminderstring",
						v="ReminderTextMultipleMines"
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="This Skill and Minions have {0}% chance to throw up to 2 additional Traps or Mines"
				}
			}
		},
		name="chance_for_2_additional_trap_mine",
		stats={
			[1]="support_additional_trap_mine_%_chance_for_2_additional_trap_mine"
		}
	},
	[8]={
		lang={
			English={
				[1]={
					[1]={
						k="reminderstring",
						v="ReminderTextMultipleMines"
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="This Skill and Minions have {0}% chance to throw up to 3 additional Traps or Mines"
				}
			}
		},
		name="chance_for_3_additional_trap_mine",
		stats={
			[1]="support_additional_trap_mine_%_chance_for_3_additional_trap_mine"
		}
	},
	["base_cast_speed_+%"]=1,
	["cast_speed_+%_when_on_low_life"]=2,
	parent="minion_skill_stat_descriptions",
	["summon_raging_spirit_melee_splash_fire_damage_only"]=5,
	["support_additional_trap_mine_%_chance_for_1_additional_trap_mine"]=6,
	["support_additional_trap_mine_%_chance_for_2_additional_trap_mine"]=7,
	["support_additional_trap_mine_%_chance_for_3_additional_trap_mine"]=8,
	["support_multicast_cast_speed_+%_final"]=3,
	["support_spell_totem_cast_speed_+%_final"]=4
}
